@@ -61,13 +61,14 @@ or
 
 =back
 
+See detail L<Mojolicious::Plugin::RoutesAuthDBI#access>
 
 =head1 SYNOPSIS
 
     $app->plugin('RoutesAuthDBI', 
-        dbh => $app->dbh,
-        auth => {...},
+        ...
         access => {< options below >},
+        ...
     );
 
 =over 4
@@ -106,6 +107,10 @@ This callback invoke when request need auth route but access was failure. $route
 
 Make initialization of class vars: $dbh, $sth, $init_conf. Return $self object.
 
+=item * B<apply_ns($app,)>
+
+Select from db table I<namespaces> ns thus app_ns=1 and push them to $app->namespaces()
+
 =item * B<apply_route($app, $r_hash)>
 
 Heart of routes generation from db tables and not only. Insert to app->routes an hash item $r_hash. DB schema specific. Return new Mojolicious route.
@@ -167,11 +172,14 @@ sub init_class {# from plugin! init Class vars
   my $c = shift;
   my %args = @_;
   $init_conf ||= $c;
-  $c->{schema} ||= 'public';
-  $c->{schema} = qq{"$c->{schema}".};
+  $c->{pos} ||= {};
+  $c->{pos}{schema} ||= 'public';
+  $c->{pos}{schema} = qq{"$c->{pos}{schema}".};
+  $c->{pos}{file} ||= 'POS/Pg.pm';
   $c->{dbh} ||= $dbh ||=  $args{dbh};
   $dbh ||= $c->{dbh};
-  $c->{sth} ||= $sth ||= $args{sth} ||=( bless [$dbh, {}, $c->{schema},], $c->{namespace}.'::Sth' )->init(pos=>$c->{pos} || $args{pos} || 'POS/Pg.pm');#sth cache
+  #~ $c->{sth} ||= $sth ||= $args{sth} ||=( bless [$dbh, {}, $c->{schema},], $c->{namespace}.'::Sth' )->init(pos=>$c->{pos} || $args{pos} || 'POS/Pg.pm');#sth cache
+  $c->{sth} ||= $sth ||= $args{sth} || Mojolicious::Plugin::RoutesAuthDBI::Sth->new($dbh, %{$c->{pos}});
   $sth ||= $c->{sth};
   return $c;
 }
@@ -193,6 +201,14 @@ sub validate_user {# import for Mojolicious::Plugin::Authentication
   return undef;
 }
 
+sub apply_ns {# Plugin
+  my ($self, $app,) = @_;
+  my $ns = $dbh->selectall_arrayref($sth->sth('namespaces', where=>"where app_ns=1::bit(1)", order=>"order by ts - (coalesce(interval_ts, 0::int)::varchar || ' second')::interval"), { Slice => {namespace=>1} },);
+  return unless @$ns;
+  my $r = $app->routes;
+  push @{ $r->namespaces() }, $_->{namespace} for @$ns;
+}
+
 sub apply_route {# meth in Plugin
   my ($self, $app, $r_hash) = @_;
   my $r = $app->routes;
